Gcm

Struct Gcm 

pub struct Gcm;
GCM (Galois/Counter Mode) for 128-bit block ciphers (i.e., AES).

Provides authenticated encryption with associated data (AEAD).

Implementations

Source

impl Gcm

pub fn encrypt<C: BlockCipher>( cipher: &C, nonce: &[u8; 12], aad: &[u8], plaintext: &[u8], ) -> (Vec<u8>, [u8; 16])

Encrypt with GCM mode.

Returns (ciphertext, tag) where tag is a 16-byte authentication tag.

Panics

Panics if the cipher block size is not 16 bytes.

pub fn decrypt<C: BlockCipher>( cipher: &C, nonce: &[u8; 12], aad: &[u8], ciphertext: &[u8], tag: &[u8; 16], ) -> Option<Vec<u8>>

Decrypt with GCM mode.

Returns Some(plaintext) if the tag verifies, None otherwise.

Panics

Panics if the cipher block size is not 16 bytes.