Error

Enum Error 

pub enum Error {
    InvalidKeyLen,
    InvalidNonceLen,
    NotInitialized,
    AlreadyFinalized,
    OutputBufferTooSmall {
        needed: usize,
    },
    WrongInitVariant,
    VerificationFailed,
}
Errors returned by Mac.

Variants



InvalidKeyLen

CMAC / GMAC: the supplied key length does not match the algorithm.



InvalidNonceLen

GMAC: the supplied nonce length is not 12 bytes.



NotInitialized

update, sign or verify was called before Mac::init.



AlreadyFinalized

update, sign or verify was called after a previous sign / verify without re-initializing.



OutputBufferTooSmall

out slice passed to sign is shorter than the algorithm’s tag length.

Fields

needed: usize

Required output length in bytes.



WrongInitVariant

Wrong init variant for the selected algorithm (e.g. init_with_nonce on HMAC, or init on GMAC).



VerificationFailed

verify failed: tag mismatch.